# SAM ONNX 

## Environment creation

> python -m venv sam_onnx_env

- Use pip 24.0 or higher version 

## Installation
In SAM_ONNX Folder
> python -m pip install -e .

## Usage
![alt text](repo_assests/demo.png)

## License

This project is licensed under the [MIT License](LICENSE).
